// Copyright (C) 2012 - N. O. Strelkov, NRU MPEI
//
// This file must be used under the terms of the GPL Version 2
// http://www.gnu.org/licenses/gpl-2.0.html

// preparing figure
hmain = scf();
s_wh = get(0, 'screensize_px');
margin_h = 50;
margin_w = 5;
max_w = s_wh(3)-2*margin_w;
max_h = s_wh(4)-2*margin_h;
h = figure(hmain, 'BackgroundColor', [1 1 1]);
h.figure_name = 'Elliptic and Cartesian coordinates';

// parameters of ellipse
a = 5; b = 4; f = sqrt(a^2 - b^2);

// additional parameters
etas_length = 25;
xi_length = 10;
xi_max = 1.5;
etas_marks_mod = 2;
xi_etas_marks = xi_max*1.06;

if (getos() == "Windows") then
  font_size_normal = 2; 
else
  font_size_normal = 3; 
end

// draw ellipse
xi = real(acosh(a/f));
eta = linspace(0, 2*%pi, 201);//0:0.01*%pi:2*%pi;
[x_el, y_el] = mathieu_ell2cart(xi, eta, f);

plot(x_el, y_el);
h = gca(); h.isoview = 'on';
xset("font size", font_size_normal);        
xtitle('$Elliptic\ and\ Cartesian\ coordinates$','$x$','$y$');



// constant angle curves (eta=const, xi=var)
etas = linspace(0, 2*%pi, etas_length);

xi_tt = linspace(0, xi_max, xi_length);
xi_t = zeros(length(xi_tt), length(etas));
eta_t = xi_t;

jc = jetcolormap(round(etas_length/2));

for i=1:etas_length
    eta_tt = etas(i);

    [xi_t, eta_t] = meshgrid(xi_tt, eta_tt);
    [x_t, y_t] = mathieu_ell2cart(xi_t, eta_t, f);
    if(eta_tt < %pi)
        jcc = jc(i,:);
    else
        jcc = jc(etas_length-i+1,:);
    end

    plot(x_t,y_t, 'Color', jcc);

    if (modulo(i, etas_marks_mod) == 0)  then    
        [mark_pos_x, mark_pos_y] = mathieu_ell2cart(xi_etas_marks, eta_tt, f);
        xstring(mark_pos_x, mark_pos_y, sprintf('$\eta=%1.0f^o$', eta_tt*180/%pi ));
    end
end


// constant ellipse curves (eta=var, xi=const)
xis = linspace(0, xi_max, xi_length);
eta_tt = linspace(0, 2*%pi, etas_length);

jc = jetcolormap(xi_length);

for j=1:xi_length
    xis_tt = xis(j);
        [x_t, y_t] = mathieu_ell2cart(xis_tt, eta_tt, f);
        plot(x_t, y_t, '--', 'Color', jc(j,:));

        [mark_pos_x, mark_pos_y] = mathieu_ell2cart(xis_tt, %pi/2, f);            
        xstring(mark_pos_x, mark_pos_y, sprintf('$\xi=%1.4f$', xis_tt ));
end

// mark foci
plot(f,0,'b*',-f,0,'b*');
xset("font size", font_size_normal+2);
xstring(f, 0, '$f$');
xstring(-f, 0, '$-f$');

// mark xi=0
xset("font size", font_size_normal);
[mark_pos_x, mark_pos_y] = mathieu_ell2cart(xi_etas_marks, 0, f);
xstring(mark_pos_x, mark_pos_y, sprintf('$\eta=%1.0f^o$', 0 ));

// mark xi=180 deg
[mark_pos_x, mark_pos_y] = mathieu_ell2cart(xi_etas_marks, %pi, f);
xstring(mark_pos_x, mark_pos_y, sprintf('$\eta=%1.0f^o$', 180 ));


// add legend
legend(sprintf('$Ellipse\ with\ a=5,\ b=4,\ f=3,\ \xi=%1.4f$', xi ), pos=-6);

  h=gcf();  
  h.figure_position = [margin_w margin_h];
  h.figure_size = [max_w max_h];
  xset("font size", font_size_normal+1);
  
  h = gca(); h.isoview = 'on'; dd=10; h.data_bounds = [-dd dd -dd dd];
  h.font_size = font_size_normal+1; h.title.font_size=font_size_normal+1; h.x_label.font_size=font_size_normal+1; h.y_label.font_size=font_size_normal+1;
  xgrid;
