// Copyright (C) 2001 - 2002 - R.Coisson & G. Vernizzi, Parma University
// Copyright (C) X. K. Yang
// Copyright (C) 2010 - 2012 - N. O. Strelkov, NRU MPEI
// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GPL Version 2
// http://www.gnu.org/licenses/gpl-2.0.html

function [x,y,zeta] = mathieu_elliptical(ty,n,m,q) 


    // mathieu_elliptical.m
    // 3D plot of a mode with elliptical boundary conditions
    // mathieu_elliptical(parity,n,m,q);
    // parity=''e'' or ''o''
    // n = radial order (Ce, Se)
    // m = angular order (ce, se)
    // q = ... modifies ellipticity (q~=0)
    // also outputs radial zeros and ellipse aspect ratio
    // do not use q=0! use q=0.01 (or smaller) or Bessel functions 
    // (q=0 implies infinite radius, as focal distance is fixed) 

    if ty=="e" then
        tr = "Ce"; 
        ta = "ce";
    end												// ''even'' mode

    if ty=="o" then
        tr = "Se"; 
        ta = "se";
    end												// ''odd'' mode

    eta=0:0.1:2*%pi+0.2;								// argument of angular function: 0 to 2*pi

    ximax=2+n^0.3*(q+0.1)^(-0.2);;					// empirical starting point
    sol=0.1;
    while length(sol)<=n
        xi0=0.01:0.01:ximax;							// trial radial range 
        f0=mathieu_mathieu(tr,m,xi0,q);
        f1=f0>0;
        f1=bool2s(f1);
        f2=diff(f1);
        sol=xi0(find(f2~=0));						// find zeroes of radial function
        ximax=ximax+1;
    end
    xi = 0:0.01:sol(n);								// argument corresponding to n-th zero    

    f = mathieu_mathieu(tr,m,xi,q);
    g = mathieu_mathieu(ta,m,eta,q);
    [x,y] = mathieu_ell2cart(xi,eta,1);						// conversion to Cartesian coord. 
    // 1 is semi-distance between foci
    axesratio=max(x)/max(y);
    ellipticity=(axesratio-1)/(axesratio+1);
    zeta=f*g';
    mass=max(zeta);
    xset("colormap",jetcolormap(128));				//set the colormap
    surf(x,y,zeta/mass*max(x),"facecol","interp"); 	//(arbitrary scaling for z)
    e=gce();
    e.color_mode=-1;								//set the color mode, vanish the mesh
    //set(gca(),"isoview","on");					//set the axises x and y equal
    set(gca(),"grid",[1,1]);
    e.color_flag=3;									//interpolate the facet, to make the surface prettier
    //contour(x,y,zeta/mass*max(max(x)),20)      	// a different display
    //
    //um=min(yy);
    //uM=max(yy);
    //colorbar(um,uM)								//show the colorbar using min and max values of yy

endfunction
